@@ -29,7 +29,6 @@ def get_exif(fn):
     print data
     """
     ret = {}
-    print fn
     i = Image.open(fn)
     info = i._getexif()
     try:
@@ -168,6 +167,7 @@ class Command(BaseCommand):
                 print "[***] Repetida: %s" % os.path.basename(filepath)
             except:
                 print "[***] La imagen %s No esta en bd, descargar y agregar a bbdd y hacer thumb" % os.path.basename(filepath)
+                #import pdb; pdb.set_trace()
                 nombre_imagen = str(os.path.basename(filepath)).replace('/', '').replace(' ','_').replace(':','-')
 
                 # Descargar original a img
