@@ -4,6 +4,7 @@
 Models for the "rgallery" project
 """
 
+import os
 import time
 import socket
 from django.db import models
@@ -13,6 +14,8 @@ from django.contrib.contenttypes import generic
 from django.template.defaultfilters import slugify
 from django.conf import settings as conf
 
+from taggit.managers import TaggableManager
+
 
 class Folder(models.Model):
 
@@ -47,11 +50,22 @@ class Photo(models.Model):
     capture_date = models.DateTimeField(_(u'Photo date'))
     folder = models.ForeignKey(Folder, related_name='photo', null=True,
                                blank=True, verbose_name=_(u'Folder'))
+    tags = TaggableManager()
     status =  models.BooleanField(_(u'Status'), default=True)
 
     def __unicode__(self):
         return str(self.image)
 
+    def split_tags(self):
+        t = []
+        for tag in self.tags.all():
+            t.append(tag.name)
+        comma = str(", ".join(t))
+        return comma
+
+    def filename(self):
+        return os.path.basename(self.image.name)
+
     class Meta:
         verbose_name = _(u'Photo')
         verbose_name_plural = _(u'Photos')
